This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
New values appearing in future releases of the client library, and
New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some
guidelines.
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
The database is fully created and ready for use, but is still
being optimized for performance and cannot handle full load.
In this state, the database still references the backup
it was restore from, preventing the backup
from being deleted. When optimizations are complete, the full performance
of the database will be restored, and the database will transition to
READY state.