#[non_exhaustive]pub struct CreateBackupEncryptionConfig {
pub encryption_type: EncryptionType,
pub kms_key_name: String,
pub kms_key_names: Vec<String>,
/* private fields */
}Expand description
Encryption configuration for the backup to create.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.encryption_type: EncryptionTypeRequired. The encryption type of the backup.
kms_key_name: StringOptional. The Cloud KMS key that will be used to protect the backup.
This field should be set only when
encryption_type
is CUSTOMER_MANAGED_ENCRYPTION. Values are of the form
projects/<project>/locations/<location>/keyRings/<key_ring>/cryptoKeys/<kms_key_name>.
kms_key_names: Vec<String>Optional. Specifies the KMS configuration for the one or more keys used to
protect the backup. Values are of the form
projects/<project>/locations/<location>/keyRings/<key_ring>/cryptoKeys/<kms_key_name>.
The keys referenced by kms_key_names must fully cover all regions of the backup’s instance configuration. Some examples:
- For single region instance configs, specify a single regional location KMS key.
- For multi-regional instance configs of type GOOGLE_MANAGED, either specify a multi-regional location KMS key or multiple regional location KMS keys that cover all regions in the instance config.
- For an instance config of type USER_MANAGED, please specify only regional location KMS keys to cover each region in the instance config. Multi-regional location KMS keys are not supported for USER_MANAGED instance configs.
Implementations
Sourceimpl CreateBackupEncryptionConfig
impl CreateBackupEncryptionConfig
Sourcepub fn set_encryption_type<T: Into<EncryptionType>>(self, v: T) -> Self
pub fn set_encryption_type<T: Into<EncryptionType>>(self, v: T) -> Self
Sets the value of encryption_type.
Example
use google_cloud_spanner_admin_database_v1::model::create_backup_encryption_config::EncryptionType;
let x0 = CreateBackupEncryptionConfig::new().set_encryption_type(EncryptionType::UseDatabaseEncryption);
let x1 = CreateBackupEncryptionConfig::new().set_encryption_type(EncryptionType::GoogleDefaultEncryption);
let x2 = CreateBackupEncryptionConfig::new().set_encryption_type(EncryptionType::CustomerManagedEncryption);Sourcepub fn set_kms_key_name<T: Into<String>>(self, v: T) -> Self
pub fn set_kms_key_name<T: Into<String>>(self, v: T) -> Self
Sets the value of kms_key_name.
Example
let x = CreateBackupEncryptionConfig::new().set_kms_key_name("example");Sourcepub fn set_kms_key_names<T, V>(self, v: T) -> Self
pub fn set_kms_key_names<T, V>(self, v: T) -> Self
Sets the value of kms_key_names.
Example
let x = CreateBackupEncryptionConfig::new().set_kms_key_names(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for CreateBackupEncryptionConfig
impl Clone for CreateBackupEncryptionConfig
Sourcefn clone(&self) -> CreateBackupEncryptionConfig
fn clone(&self) -> CreateBackupEncryptionConfig
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CreateBackupEncryptionConfig
impl Debug for CreateBackupEncryptionConfig
Sourceimpl Default for CreateBackupEncryptionConfig
impl Default for CreateBackupEncryptionConfig
Sourcefn default() -> CreateBackupEncryptionConfig
fn default() -> CreateBackupEncryptionConfig
impl StructuralPartialEq for CreateBackupEncryptionConfig