#[non_exhaustive]pub struct CreateBackupMetadata {
pub name: String,
pub database: String,
pub progress: Option<OperationProgress>,
pub cancel_time: Option<Timestamp>,
/* private fields */
}Expand description
Metadata type for the operation returned by CreateBackup.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe name of the backup being created.
database: StringThe name of the database the backup is created from.
progress: Option<OperationProgress>The progress of the CreateBackup operation.
cancel_time: Option<Timestamp>The time at which cancellation of this operation was received.
[Operations.CancelOperation][google.longrunning.Operations.CancelOperation]
starts asynchronous cancellation on a long-running operation. The server
makes a best effort to cancel the operation, but success is not guaranteed.
Clients can use
[Operations.GetOperation][google.longrunning.Operations.GetOperation] or
other methods to check whether the cancellation succeeded or whether the
operation completed despite cancellation. On successful cancellation,
the operation is not deleted; instead, it becomes an operation with
an Operation.error value with a
google.rpc.Status.code of 1,
corresponding to Code.CANCELLED.
Implementations
Sourceimpl CreateBackupMetadata
impl CreateBackupMetadata
Sourcepub fn set_database<T: Into<String>>(self, v: T) -> Self
pub fn set_database<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_progress<T>(self, v: T) -> Selfwhere
T: Into<OperationProgress>,
pub fn set_progress<T>(self, v: T) -> Selfwhere
T: Into<OperationProgress>,
Sourcepub fn set_or_clear_progress<T>(self, v: Option<T>) -> Selfwhere
T: Into<OperationProgress>,
pub fn set_or_clear_progress<T>(self, v: Option<T>) -> Selfwhere
T: Into<OperationProgress>,
Sets or clears the value of progress.
Example
use google_cloud_spanner_admin_database_v1::model::OperationProgress;
let x = CreateBackupMetadata::new().set_or_clear_progress(Some(OperationProgress::default()/* use setters */));
let x = CreateBackupMetadata::new().set_or_clear_progress(None::<OperationProgress>);Sourcepub fn set_cancel_time<T>(self, v: T) -> Self
pub fn set_cancel_time<T>(self, v: T) -> Self
Sets the value of cancel_time.
Example
use wkt::Timestamp;
let x = CreateBackupMetadata::new().set_cancel_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_cancel_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_cancel_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of cancel_time.
Example
use wkt::Timestamp;
let x = CreateBackupMetadata::new().set_or_clear_cancel_time(Some(Timestamp::default()/* use setters */));
let x = CreateBackupMetadata::new().set_or_clear_cancel_time(None::<Timestamp>);Trait Implementations
Sourceimpl Clone for CreateBackupMetadata
impl Clone for CreateBackupMetadata
Sourcefn clone(&self) -> CreateBackupMetadata
fn clone(&self) -> CreateBackupMetadata
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CreateBackupMetadata
impl Debug for CreateBackupMetadata
Sourceimpl Default for CreateBackupMetadata
impl Default for CreateBackupMetadata
Sourcefn default() -> CreateBackupMetadata
fn default() -> CreateBackupMetadata
Sourceimpl Message for CreateBackupMetadata
impl Message for CreateBackupMetadata
Sourceimpl PartialEq for CreateBackupMetadata
impl PartialEq for CreateBackupMetadata
impl StructuralPartialEq for CreateBackupMetadata