#[non_exhaustive]pub struct RestoreDatabaseEncryptionConfig {
pub encryption_type: EncryptionType,
pub kms_key_name: String,
pub kms_key_names: Vec<String>,
/* private fields */
}Expand description
Encryption configuration for the restored database.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.encryption_type: EncryptionTypeRequired. The encryption type of the restored database.
kms_key_name: StringOptional. The Cloud KMS key that will be used to encrypt/decrypt the
restored database. This field should be set only when
encryption_type
is CUSTOMER_MANAGED_ENCRYPTION. Values are of the form
projects/<project>/locations/<location>/keyRings/<key_ring>/cryptoKeys/<kms_key_name>.
kms_key_names: Vec<String>Optional. Specifies the KMS configuration for the one or more keys used to
encrypt the database. Values are of the form
projects/<project>/locations/<location>/keyRings/<key_ring>/cryptoKeys/<kms_key_name>.
The keys referenced by kms_key_names must fully cover all regions of the database instance configuration. Some examples:
- For single region database instance configs, specify a single regional location KMS key.
- For multi-regional database instance configs of type GOOGLE_MANAGED, either specify a multi-regional location KMS key or multiple regional location KMS keys that cover all regions in the instance config.
- For a database instance config of type USER_MANAGED, please specify only regional location KMS keys to cover each region in the instance config. Multi-regional location KMS keys are not supported for USER_MANAGED instance configs.
Implementations
Sourceimpl RestoreDatabaseEncryptionConfig
impl RestoreDatabaseEncryptionConfig
Sourcepub fn set_encryption_type<T: Into<EncryptionType>>(self, v: T) -> Self
pub fn set_encryption_type<T: Into<EncryptionType>>(self, v: T) -> Self
Sets the value of encryption_type.
Example
use google_cloud_spanner_admin_database_v1::model::restore_database_encryption_config::EncryptionType;
let x0 = RestoreDatabaseEncryptionConfig::new().set_encryption_type(EncryptionType::UseConfigDefaultOrBackupEncryption);
let x1 = RestoreDatabaseEncryptionConfig::new().set_encryption_type(EncryptionType::GoogleDefaultEncryption);
let x2 = RestoreDatabaseEncryptionConfig::new().set_encryption_type(EncryptionType::CustomerManagedEncryption);Sourcepub fn set_kms_key_name<T: Into<String>>(self, v: T) -> Self
pub fn set_kms_key_name<T: Into<String>>(self, v: T) -> Self
Sets the value of kms_key_name.
Example
let x = RestoreDatabaseEncryptionConfig::new().set_kms_key_name("example");Sourcepub fn set_kms_key_names<T, V>(self, v: T) -> Self
pub fn set_kms_key_names<T, V>(self, v: T) -> Self
Sets the value of kms_key_names.
Example
let x = RestoreDatabaseEncryptionConfig::new().set_kms_key_names(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for RestoreDatabaseEncryptionConfig
impl Clone for RestoreDatabaseEncryptionConfig
Sourcefn clone(&self) -> RestoreDatabaseEncryptionConfig
fn clone(&self) -> RestoreDatabaseEncryptionConfig
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for RestoreDatabaseEncryptionConfig
impl Default for RestoreDatabaseEncryptionConfig
Sourcefn default() -> RestoreDatabaseEncryptionConfig
fn default() -> RestoreDatabaseEncryptionConfig
impl StructuralPartialEq for RestoreDatabaseEncryptionConfig